==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp3441_001/MP3441_GetNonconformityObservationDefault_001.java <==

package net.datastream.schemas.mp_functions.mp3441_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STANDARDENTITYID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="NonconformityObservationDefault" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "nonconformityid",
    "organizationid"
})
@XmlRootElement(name = "MP3441_GetNonconformityObservationDefault_001")
public class MP3441_GetNonconformityObservationDefault_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "NONCONFORMITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STANDARDENTITYID_Type nonconformityid;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the nonconformityid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getNONCONFORMITYID() {
        return nonconformityid;
    }

    /**
     * Sets the value of the nonconformityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setNONCONFORMITYID(STANDARDENTITYID_Type value) {
        this.nonconformityid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.NONCONFORMITY_OBSERVATION_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_functions/mp3441_001/MP3441_GetNonconformityObservationDefault_001.java <==

package net.datastream.schemas.mp_functions.mp3441_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STANDARDENTITYID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;
import net.datastream.schemas.mp_fields.WOID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="NonconformityObservationDefault" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workorderid",
    "nonconformityid",
    "organizationid"
})
@XmlRootElement(name = "MP3441_GetNonconformityObservationDefault_001")
public class MP3441_GetNonconformityObservationDefault_001 {

    @XmlElement(name = "WORKORDERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type workorderid;
    @XmlElement(name = "NONCONFORMITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STANDARDENTITYID_Type nonconformityid;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

    /**
     * Gets the value of the nonconformityid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getNONCONFORMITYID() {
        return nonconformityid;
    }

    /**
     * Sets the value of the nonconformityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setNONCONFORMITYID(STANDARDENTITYID_Type value) {
        this.nonconformityid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.NONCONFORMITY_OBSERVATION_DEFAULT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
